Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/__init__.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/__init__.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/__init__.py	(revision 11949)
@@ -1,2 +1,2 @@
-"""JS-driven widgets for Kofa.
+"""JS-driven widgets for Ikoba.
 """
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/datewidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/datewidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/datewidget.py	(revision 11949)
@@ -26,6 +26,6 @@
 from zope.formlib.widget import renderElement, CustomWidgetFactory
 from zope.interface import implements
-from waeup.kofa.interfaces import IKofaUtils
-from waeup.kofa.utils.helpers import to_timezone
+from waeup.ikoba.interfaces import IIkobaUtils
+from waeup.ikoba.utils.helpers import to_timezone
 
 
@@ -82,5 +82,5 @@
     If the widget is bound to a schema field with respective
     attributes, it reads its `show_year` and `date_format` attributes
-    (see waeup.kofa.schema.FormattedDate for an example) and sets a
+    (see waeup.ikoba.schema.FormattedDate for an example) and sets a
     CSS tag according to these values.
 
@@ -141,5 +141,5 @@
     It can also be used for displaying datetimes. If used to display a
     datetime (not a date), the widget returns local datetime with
-    timezone set according to KofaUtils.
+    timezone set according to IkobaUtils.
     """
     date_format = '%Y-%m-%d'
@@ -167,5 +167,5 @@
             # shift value to local timezone
             tz = pytz.utc
-            utils = queryUtility(IKofaUtils)
+            utils = queryUtility(IIkobaUtils)
             if utils is not None:
                 tz = utils.tzinfo
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/objectwidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/objectwidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/objectwidget.py	(revision 11949)
@@ -25,8 +25,8 @@
 from zope.schema import getFieldNamesInOrder
 
-class KofaObjectWidgetView(ObjectWidgetView):
+class IkobaObjectWidgetView(ObjectWidgetView):
     template = ViewPageTemplateFile('objectwidget.pt')
 
-class KofaObjectWidget(ObjectWidget):
+class IkobaObjectWidget(ObjectWidget):
 
     def __init__(self, context, request, factory, **kw):
@@ -58,8 +58,8 @@
 
     def _getView(self, request):
-        return KofaObjectWidgetView(self, request)
+        return IkobaObjectWidgetView(self, request)
 
 
-class KofaObjectDisplayWidget(KofaObjectWidget):
+class IkobaObjectDisplayWidget(IkobaObjectWidget):
 
     implementsOnly(IDisplayWidget)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/overrides.zcml
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/overrides.zcml	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/overrides.zcml	(revision 11949)
@@ -5,21 +5,21 @@
            zope.publisher.interfaces.browser.IBrowserRequest"
       provides="zope.formlib.interfaces.ISimpleInputWidget"
-      factory="waeup.kofa.widgets.datewidget.FormattedDateWidget"
+      factory="waeup.ikoba.widgets.datewidget.FormattedDateWidget"
       permission="zope.Public"
       />
 
   <adapter
-      for="waeup.kofa.schema.interfaces.IFormattedDate
+      for="waeup.ikoba.schema.interfaces.IFormattedDate
            zope.publisher.interfaces.browser.IBrowserRequest"
       provides="zope.formlib.interfaces.ISimpleInputWidget"
-      factory="waeup.kofa.widgets.datewidget.DateLEWidget"
+      factory="waeup.ikoba.widgets.datewidget.DateLEWidget"
       permission="zope.Public"
       />
 
   <adapter
-      for="waeup.kofa.schema.interfaces.IFormattedDate
+      for="waeup.ikoba.schema.interfaces.IFormattedDate
            zope.publisher.interfaces.browser.IBrowserRequest"
       provides="zope.formlib.interfaces.IDisplayWidget"
-      factory="waeup.kofa.widgets.datewidget.DateLEDisplayWidget"
+      factory="waeup.ikoba.widgets.datewidget.DateLEDisplayWidget"
       permission="zope.Public"
       />
@@ -27,8 +27,8 @@
   <!-- Register edit widget for PhoneNumbers -->
   <adapter
-      for="waeup.kofa.schema.interfaces.IPhoneNumber
+      for="waeup.ikoba.schema.interfaces.IPhoneNumber
            zope.publisher.interfaces.browser.IBrowserRequest"
       provides="zope.formlib.interfaces.ISimpleInputWidget"
-      factory="waeup.kofa.widgets.phonewidget.PhoneWidget"
+      factory="waeup.ikoba.widgets.phonewidget.PhoneWidget"
       permission="zope.Public"
       />
@@ -39,5 +39,5 @@
            zope.publisher.interfaces.browser.IBrowserRequest"
       provides="zope.formlib.interfaces.ISimpleInputWidget"
-      factory="waeup.kofa.widgets.datetimewidget.PytzDatetimeWidget"
+      factory="waeup.ikoba.widgets.datetimewidget.PytzDatetimeWidget"
       permission="zope.Public"
       />
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/phonewidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/phonewidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/phonewidget.py	(revision 11949)
@@ -26,7 +26,7 @@
 from zope.formlib.textwidgets import (
     TextWidget, renderElement, ConversionError)
-from waeup.kofa.interfaces import IKofaUtils
-from waeup.kofa.interfaces import MessageFactory as _
-from waeup.kofa.utils.utils import KofaUtils
+from waeup.ikoba.interfaces import IIkobaUtils
+from waeup.ikoba.interfaces import MessageFactory as _
+from waeup.ikoba.utils.utils import IkobaUtils
 
 RE_INT_PREFIX = re.compile('^\+\d+')
@@ -41,6 +41,6 @@
     def _renderPrefixWidget(self, value):
         prefix_func = getattr(
-            queryUtility(IKofaUtils), 'sorted_phone_prefixes',
-            KofaUtils.sorted_phone_prefixes)
+            queryUtility(IIkobaUtils), 'sorted_phone_prefixes',
+            IkobaUtils.sorted_phone_prefixes)
         options = []
         for ptitle, pval in prefix_func(request=self.request):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/sequencewidget.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/sequencewidget.pt	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/sequencewidget.pt	(revision 11949)
@@ -1,3 +1,3 @@
-<table i18n:domain="waeup.kofa">
+<table i18n:domain="waeup.ikoba">
   <tr tal:repeat="widget view/widgets">
     <td>
@@ -27,6 +27,6 @@
              tal:attributes="name string:${view/name}.remove"
              i18n:translate="remove-selected-items">Remove selected items</button>
-      <a id="kofa-scroll-target"
-         tal:condition="view/_kofa_seq_len_changed" />
+      <a id="ikoba-scroll-target"
+         tal:condition="view/_ikoba_seq_len_changed" />
     </td>
   </tr>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/sequencewidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/sequencewidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/sequencewidget.py	(revision 11949)
@@ -31,5 +31,5 @@
 
 
-class KofaSequenceWidget(ListSequenceWidget):
+class IkobaSequenceWidget(ListSequenceWidget):
     """A sequence widget for lists.
 
@@ -38,15 +38,15 @@
     """
     template = ViewPageTemplateFile('sequencewidget.pt')
-    _kofa_seq_len_changed = False
+    _ikoba_seq_len_changed = False
 
     def _generateSequence(self):
-        result = super(KofaSequenceWidget, self)._generateSequence()
+        result = super(IkobaSequenceWidget, self)._generateSequence()
         if ((self.name + '.add' in self.request.form) or
             (self.name + '.remove' in self.request.form)):
-            self._kofa_seq_len_changed = True
+            self._ikoba_seq_len_changed = True
         return result
 
 
-class KofaSequenceDisplayWidget(SequenceDisplayWidget):
+class IkobaSequenceDisplayWidget(SequenceDisplayWidget):
     """A sequence widget for lists.
 
@@ -100,5 +100,5 @@
 @grok.implementer(IInputWidget)
 def seq_input_widget(obj, field, req, *args, **kw):
-    return KofaSequenceWidget(obj, field, req, *args, **kw)
+    return IkobaSequenceWidget(obj, field, req, *args, **kw)
 
 
@@ -106,3 +106,3 @@
 @grok.implementer(IDisplayWidget)
 def seq_display_widget(obj, field, req, *args, **kw):
-    return KofaSequenceDisplayWidget(obj, field, req, *args, **kw)
+    return IkobaSequenceDisplayWidget(obj, field, req, *args, **kw)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/tests/test_datetimewidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/tests/test_datetimewidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/tests/test_datetimewidget.py	(revision 11949)
@@ -12,6 +12,6 @@
 from zope.interface.verify import verifyClass, verifyObject
 from zope.publisher.browser import TestRequest
-from waeup.kofa.interfaces import IKofaUtils
-from waeup.kofa.widgets.datetimewidget import PytzDatetimeWidget
+from waeup.ikoba.interfaces import IIkobaUtils
+from waeup.ikoba.widgets.datetimewidget import PytzDatetimeWidget
 
 class IContent(Interface):
@@ -30,5 +30,5 @@
 class FakeUtils(object):
     # Fake app-wide set timezone.
-    implements(IKofaUtils)
+    implements(IIkobaUtils)
     tzinfo = pytz.timezone('America/Sao_Paulo')
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/tests/test_datewidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/tests/test_datewidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/tests/test_datewidget.py	(revision 11949)
@@ -29,5 +29,5 @@
     SimpleInputWidgetTest, BrowserWidgetTest, )
 from zope.formlib.interfaces import IInputWidget, IDisplayWidget
-from waeup.kofa.widgets.datewidget import (
+from waeup.ikoba.widgets.datewidget import (
     FormattedDateWidget, FormattedDateDisplayWidget, )
 from zope.formlib.widgets import DateI18nWidget
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/tests/test_objectwidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/tests/test_objectwidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/tests/test_objectwidget.py	(revision 11949)
@@ -37,7 +37,7 @@
 from zope.formlib.interfaces import IWidgetInputErrorView
 
-from waeup.kofa.widgets.objectwidget import KofaObjectWidget as ObjectWidget
-from waeup.kofa.widgets.objectwidget import (
-    KofaObjectDisplayWidget as ObjectDisplayWidget)
+from waeup.ikoba.widgets.objectwidget import IkobaObjectWidget as ObjectWidget
+from waeup.ikoba.widgets.objectwidget import (
+    IkobaObjectDisplayWidget as ObjectDisplayWidget)
 
 class ITestContact(Interface):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/tests/test_phonewidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/tests/test_phonewidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/tests/test_phonewidget.py	(revision 11949)
@@ -30,5 +30,5 @@
 from zope.publisher.browser import TestRequest
 from zope.schema.interfaces import ITextLine
-from waeup.kofa.widgets.phonewidget import PhoneWidget
+from waeup.ikoba.widgets.phonewidget import PhoneWidget
 
 # Dummy content

Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/datetimewidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/datetimewidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/datetimewidget.py	(revision 11949)
@@ -26,11 +26,11 @@
 from zope.formlib.interfaces import ConversionError
 from zope.formlib.textwidgets import DatetimeWidget
-from waeup.kofa.utils.helpers import to_timezone
-from waeup.kofa.interfaces import IKofaUtils
+from waeup.ikoba.utils.helpers import to_timezone
+from waeup.ikoba.interfaces import IIkobaUtils
 
 class _DummyUtils(object):
     tzinfo = pytz.utc
 
 # A fallback, if no IKofaUtils can be found
 _DUMMY_UTILS = _DummyUtils()
 
@@ -85,5 +85,5 @@
             return value
         if value.tzinfo is None:
-            utils = queryUtility(IKofaUtils, default=_DUMMY_UTILS)
+            utils = queryUtility(IIkobaUtils, default=_DUMMY_UTILS)
             value = utils.tzinfo.localize(value)
         return value.astimezone(pytz.utc)
@@ -26,11 +26,11 @@
     tzinfo = pytz.utc
 
-# A fallback, if no IKofaUtils can be found
+# A fallback, if no IIkobaUtils can be found
 _DUMMY_UTILS = _DummyUtils()
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/htmlwidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/htmlwidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/htmlwidget.py	(revision 11949)
@@ -20,5 +20,5 @@
 from zope.component import getUtility
 from zope.formlib.widget import renderElement, DisplayWidget
-from waeup.kofa.interfaces import IKofaUtils
+from waeup.ikoba.interfaces import IIkobaUtils
 
 
@@ -35,5 +35,5 @@
         language separator - usually the first part has no language
         descriptor - are interpreted as texts in the portal's language.
         The latter can be configured in waeup.srp.utils.utils.KofaUtils.
         """
         if self._renderedValueSet():
@@ -45,5 +45,5 @@
         parts = value.split('>>')
         elements = {}
-        lang = getUtility(IKofaUtils).PORTAL_LANGUAGE
+        lang = getUtility(IIkobaUtils).PORTAL_LANGUAGE
         for part in parts:
             if part[2:4] == u'<<':
@@ -35,5 +35,5 @@
         language separator - usually the first part has no language
         descriptor - are interpreted as texts in the portal's language.
-        The latter can be configured in waeup.srp.utils.utils.KofaUtils.
+        The latter can be configured in waeup.srp.utils.utils.IkobaUtils.
         """
         if self._renderedValueSet():
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/restwidget.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/widgets/restwidget.py	(revision 11945)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/widgets/restwidget.py	(revision 11949)
@@ -20,6 +20,6 @@
 from zope.component import getUtility
 from zope.formlib.widget import renderElement, DisplayWidget
-from waeup.kofa.utils.helpers import ReST2HTML
-from waeup.kofa.interfaces import IKofaUtils
+from waeup.ikoba.utils.helpers import ReST2HTML
+from waeup.ikoba.interfaces import IIkobaUtils
 
 
@@ -36,5 +36,5 @@
         language separator - usually the first part has no language
         descriptor - are interpreted as texts in the portal's language.
         The latter can be configured in waeup.srp.utils.utils.KofaUtils.
         """
         if self._renderedValueSet():
@@ -46,5 +46,5 @@
         parts = value.split('>>')
         elements = {}
-        lang = getUtility(IKofaUtils).PORTAL_LANGUAGE
+        lang = getUtility(IIkobaUtils).PORTAL_LANGUAGE
         for part in parts:
             if part[2:4] == u'<<':
@@ -36,5 +36,5 @@
         language separator - usually the first part has no language
         descriptor - are interpreted as texts in the portal's language.
-        The latter can be configured in waeup.srp.utils.utils.KofaUtils.
+        The latter can be configured in waeup.srp.utils.utils.IkobaUtils.
         """
         if self._renderedValueSet():